@@ -25,11 +25,11 @@ class Command(BaseCommand):
         if not setupfile:
             raise CommandError("You must provide the path to your apps setup.py as first argument")
         if not appfile:
-            raise CommandError("You must provide the path to your app file as first argument")
+            raise CommandError("You must provide the path to your app file as second argument")
         if not os.path.exists(setupfile):
             raise CommandError("Could not find setup.py at %r" % setupfile)
         if not os.path.exists(appfile):
-            raise CommandError("Could not find setup.py at %r" % appfile)
+            raise CommandError("Could not find app file at %r" % appfile)
         username, password = self.get_auth(options['noinput'])
         self.run(setupfile, appfile, username, password, **options)
 
@@ -50,6 +50,7 @@ class Command(BaseCommand):
         elif response.status_code == 403:
             printer.error("Authentication failed")
             printer.always("Upload failed")
+            self.clear_auth()
         elif response.status_code == 502:
             printer.error("Temporarily unavailable")
             printer.always("Upload failed")
