@@ -10,7 +10,8 @@ INVALID_CONFIG = 6
 MISSING_TEMPLATE = 7
 NAME_MISMATCH = 8
 VERSION_TOO_LOW = 9
-PRIVATE_APP_QUOTA = 10
+PRIVATE_BOILERPLATE_QUOTA = PRIVATE_APP_QUOTA = 10
 INVALID_WEBSITE = 11
 INVALID_FILENAME = 12
 NO_WEBSITE = 13
+MISSING_STATIC = 14
